==> magento-framework-100.1.18.zip: Search/Request/Config/FilesystemReader.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Magento\Framework\Search\Request\Config;

class FilesystemReader extends \Magento\Framework\Config\Reader\Filesystem
{
    /**
     * List of identifier attributes for merging
     *
     * @var array
     */
    protected $_idAttributes = [
        '/requests/request' => 'query',
        '/requests/request/queries/query' => 'name',
        '/requests/request/queries/query/queryReference' => 'ref',
        '/requests/request/queries/query/match' => 'field',
        '/requests/request/queries/query/filterReference' => 'ref',
        '/requests/request/filters/filter' => 'name',
        '/requests/request/filters/filter/filterReference' => 'ref',
        '/requests/request/aggregations/bucket' => 'name',
        '/requests/request/dimensions/dimension' => 'name',
    ];

    /**
     * @param \Magento\Framework\Config\FileResolverInterface $fileResolver
     * @param Converter $converter
     * @param SchemaLocator $schemaLocator
     * @param \Magento\Framework\Config\ValidationStateInterface $validationState
     * @param string $fileName
     * @param array $idAttributes
     * @param string $domDocumentClass
     * @param string $defaultScope
     */
    public function __construct(
        \Magento\Framework\Config\FileResolverInterface $fileResolver,
        \Magento\Framework\Search\Request\Config\Converter $converter,
        \Magento\Framework\Search\Request\Config\SchemaLocator $schemaLocator,
        \Magento\Framework\Config\ValidationStateInterface $validationState,
        $fileName = 'search_request.xml',
        $idAttributes = [],
        $domDocumentClass = 'Magento\Framework\Config\Dom',
        $defaultScope = 'global'
    ) {
        parent::__construct(
            $fileResolver,
            $converter,
            $schemaLocator,
            $validationState,
            $fileName,
            $idAttributes,
            $domDocumentClass,
            $defaultScope
        );
    }
}

==> magento-framework-100.2.0-rc20.zip: Search/Request/Config/FilesystemReader.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Magento\Framework\Search\Request\Config;

/**
 * Class \Magento\Framework\Search\Request\Config\FilesystemReader
 *
 */
class FilesystemReader extends \Magento\Framework\Config\Reader\Filesystem
{
    /**
     * List of identifier attributes for merging
     *
     * @var array
     */
    protected $_idAttributes = [
        '/requests/request' => 'query',
        '/requests/request/queries/query' => 'name',
        '/requests/request/queries/query/queryReference' => 'ref',
        '/requests/request/queries/query/match' => 'field',
        '/requests/request/queries/query/filterReference' => 'ref',
        '/requests/request/filters/filter' => 'name',
        '/requests/request/filters/filter/filterReference' => 'ref',
        '/requests/request/aggregations/bucket' => 'name',
        '/requests/request/dimensions/dimension' => 'name',
    ];

    /**
     * @param \Magento\Framework\Config\FileResolverInterface $fileResolver
     * @param Converter $converter
     * @param SchemaLocator $schemaLocator
     * @param \Magento\Framework\Config\ValidationStateInterface $validationState
     * @param string $fileName
     * @param array $idAttributes
     * @param string $domDocumentClass
     * @param string $defaultScope
     */
    public function __construct(
        \Magento\Framework\Config\FileResolverInterface $fileResolver,
        \Magento\Framework\Search\Request\Config\Converter $converter,
        \Magento\Framework\Search\Request\Config\SchemaLocator $schemaLocator,
        \Magento\Framework\Config\ValidationStateInterface $validationState,
        $fileName = 'search_request.xml',
        $idAttributes = [],
        $domDocumentClass = \Magento\Framework\Config\Dom::class,
        $defaultScope = 'global'
    ) {
        parent::__construct(
            $fileResolver,
            $converter,
            $schemaLocator,
            $validationState,
            $fileName,
            $idAttributes,
            $domDocumentClass,
            $defaultScope
        );
    }
}
